==> kdevplatform-1.5.80.tar.xz: kdevplatform-1.5.80/plugins/snippet/kdevsnippet.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Icon=edit-copy
Comment=This plugin allows to store code snippets and insert them into open files
Comment[bg]=Тази приставка позволява съхраняването на временни фрагменти от програмни низове и вмъкването им в отворени файлове
Comment[bs]=Ovaj dodatak omogućava da sačuvate isječke koda i unesete ih u otvorenu datoteku.
Comment[ca]=Aquest connector permet desar retalls de codi i inserir-los a fitxers oberts
Comment[ca@valencia]=Este connector permet guardar retalls de codi i inserir-los a fitxers oberts
Comment[da]=Dette plugin tillader at gemme kodestumper og indsætte dem i åbne filer
Comment[de]=Dieses Modul bietet die Möglichkeit, Textbausteine zu speichern und in geöffnete Dateien einzufügen.
Comment[el]=Αυτό το πρόσθετο σας επιτρέπει να αποθηκεύσετε δείγματα κώδικα και να τα εισάγετε σε ανοιχτά αρχεία
Comment[en_GB]=This plugin allows to store code snippets and insert them into open files
Comment[es]=Este complemento le permite almacenar fragmentos de código e insertarlos en los archivos abiertos
Comment[et]=See plugin võimaldab salvestada koodijuppe ja lisada neid avatud failidesse
Comment[fi]=Tämä liitännäinen mahdollistaa tallentaa koodikatkelmia ja lisätä ne avoimiin tiedostoihin
Comment[fr]=Ce module externe permet d'enregistrer des fragments de code et de les insérer dans les fichiers ouverts
Comment[gl]=Este complemento permite gardar fragmentos de código e inserilos en ficheiros abertos
Comment[hu]=Ez a bővítmény lehetővé teszi kódtöredékek tárolását és azok beszúrását a megnyitott fájlokba
Comment[it]=Questa estensione permette di memorizzare i frammenti di codice e inserirli in file aperti
Comment[kk]=Код үзінділерін сақтап, керегінде ашық файлдарға енгізу плагині
Comment[nb]=Dette programtillegget kan lagre kodebiter og sette dem inn i åpne filer
Comment[nds]=Dit Moduul wohrt Kodesnippels un föögt se na opmaakt Dateien in
Comment[nl]=Deze plugin biedt het opslaan van codefragmenten en voegt ze in in open bestanden
Comment[pl]=Ta wtyczka umożliwia zapisanie wstawek kodu i wstawianie ich później otwartych plików
Comment[pt]=Este 'plugin' permite-lhe guardar excertos de código e inseri-los nos ficheiros abertos
Comment[pt_BR]=Este plugin permite armazenar trechos de código e inseri-los em arquivos abertos
Comment[ru]=Это расширение позволяет хранить фрагменты кода и вставлять их в открытые файлы.
Comment[sk]=Tento plugin umožňuje uložiť útržky kódu a vložiť ich do otvorených súborov
Comment[sl]=Vstavek omogoča shranjevanje izrezkov kode in njihovo vstavljanje v odprte datoteke
Comment[sv]=Insticksprogrammet gör det möjligt att lagra kodsnuttar och infoga dem i öppna filer
Comment[tr]=Bu eklenti, kod parçacıklarını depolamayı ve bu kod parçacıklarını açık olan dosyalara eklemeyi sağlar
Comment[uk]=За допомогою цього додатка можна зберігати фрагменти коду і вставляти їх до відкритих файлів
Comment[x-test]=xxThis plugin allows to store code snippets and insert them into open filesxx
Comment[zh_CN]=此插件允许存储代码片断并插入到打开的文件中去
Comment[zh_TW]=此外掛程式允許儲存程式碼片段，並將它們插入開啟的檔案中
Name=Code Snippets Support
Name[bg]=Поддръжка на отрязъци от код
Name[bs]=Podrška za isječke koda
Name[ca]=Implementació de retalls de codi
Name[ca@valencia]=Implementació de retalls de codi
Name[da]=Understøttelse af kodestumper
Name[de]=Unterstützung für Textbausteine
Name[el]=Υποστήριξη αποσπασμάτων κώδικα
Name[en_GB]=Code Snippets Support
Name[es]=Implementación de fragmentos de código
Name[et]=Koodijuppide toetus
Name[fi]=Koodikatkelmatuki
Name[fr]=Prise en charge des fragments de code
Name[gl]=Soporte de fragmentos de código
Name[hu]=Kódtöredékek támogatás
Name[it]=Supporto frammenti di codice
Name[ja]=コードスニペットのサポート
Name[kk]=Код фрагменттері
Name[nb]=Støtte for kodebiter
Name[nds]=Kodesnippels-Ünnerstütten
Name[nl]=Ondersteuning voor codeknipsels
Name[pa]=ਕੋਡ ਸਨਿੱਪਟ ਸਹਿਯੋਗ
Name[pl]=Obsługa wstawek kodu
Name[pt]=Suporte para Excertos de Código
Name[pt_BR]=Suporte a trechos de código
Name[ru]=Поддержка фрагментов кода
Name[sk]=Podpora útržkov kódu
Name[sl]=Podpora za izrezke kode
Name[sv]=Stöd för kodsnuttar
Name[tr]=Kod Parçacıkları Desteği
Name[ug]=كود پۇرۇچلىرىنى قوللاش
Name[uk]=Підтримка фрагментів коду
Name[x-test]=xxCode Snippets Supportxx
Name[zh_CN]=代码片断支持
Name[zh_TW]=程式碼片段支援
GenericName=Code Snippets Support
GenericName[bg]=Поддръжка на отрязъци от код
GenericName[bs]=Podrška za isječke koda
GenericName[ca]=Implementació de retalls de codi
GenericName[ca@valencia]=Implementació de retalls de codi
GenericName[da]=Understøttelse af kodestumper
GenericName[de]=Unterstützung für Textbausteine
GenericName[el]=Υποστήριξη αποσπασμάτων κώδικα
GenericName[en_GB]=Code Snippets Support
GenericName[es]=Implementación de fragmentos de código
GenericName[et]=Koodijuppide toetus
GenericName[fi]=Koodikatkelmatuki
GenericName[fr]=Prise en charge des fragments de code
GenericName[gl]=Soporte de fragmentos de código
GenericName[hu]=Kódtöredékek támogatás
GenericName[it]=Supporto frammenti di codice
GenericName[ja]=コードスニペットのサポート
GenericName[kk]=Код фрагменттері
GenericName[nb]=Støtte for kodebiter
GenericName[nds]=Kodesnippels-Ünnerstütten
GenericName[nl]=Ondersteuning voor codeknipsels
GenericName[pl]=Obsługa wstawek kodu
GenericName[pt]=Suporte para Excertos de Código
GenericName[pt_BR]=Suporte a trechos de código
GenericName[ru]=Поддержка фрагментов кода
GenericName[sk]=Podpora útržkov kódu
GenericName[sl]=Podpora za izrezke kode
GenericName[sv]=Stöd för kodsnuttar
GenericName[tr]=Kod Parçacıkları Desteği
GenericName[ug]=كود پۇرۇچلىرىنى قوللاش
GenericName[uk]=Підтримка фрагментів коду
GenericName[x-test]=xxCode Snippets Supportxx
GenericName[zh_CN]=代码片断支持
GenericName[zh_TW]=程式碼片段支援
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevsnippet
X-KDE-PluginInfo-Name=kdevsnippet
X-KDE-PluginInfo-Author=Robert Gruber, Milian Wolff
X-KDE-PluginInfo-Version=0.75
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Mode=GUI

==> kdevplatform-1.5.90.tar.xz: kdevplatform-1.5.90/plugins/snippet/kdevsnippet.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Icon=edit-copy
Comment=This plugin allows to store code snippets and insert them into open files
Comment[bg]=Тази приставка позволява съхраняването на временни фрагменти от програмни низове и вмъкването им в отворени файлове
Comment[bs]=Ovaj dodatak omogućava da sačuvate isječke koda i unesete ih u otvorenu datoteku.
Comment[ca]=Aquest connector permet desar retalls de codi i inserir-los als fitxers oberts
Comment[ca@valencia]=Este connector permet guardar retalls de codi i inserir-los a fitxers oberts
Comment[da]=Dette plugin tillader at gemme kodestumper og indsætte dem i åbne filer
Comment[de]=Dieses Modul bietet die Möglichkeit, Textbausteine zu speichern und in geöffnete Dateien einzufügen.
Comment[el]=Αυτό το πρόσθετο σας επιτρέπει να αποθηκεύσετε δείγματα κώδικα και να τα εισάγετε σε ανοιχτά αρχεία
Comment[en_GB]=This plugin allows to store code snippets and insert them into open files
Comment[es]=Este complemento le permite almacenar fragmentos de código e insertarlos en los archivos abiertos
Comment[et]=See plugin võimaldab salvestada koodijuppe ja lisada neid avatud failidesse
Comment[fi]=Tämä liitännäinen mahdollistaa tallentaa koodikatkelmia ja lisätä ne avoimiin tiedostoihin
Comment[fr]=Ce module externe permet d'enregistrer des fragments de code et de les insérer dans les fichiers ouverts
Comment[gl]=Este complemento permite gardar fragmentos de código e inserilos en ficheiros abertos
Comment[hu]=Ez a bővítmény lehetővé teszi kódtöredékek tárolását és azok beszúrását a megnyitott fájlokba
Comment[it]=Questa estensione permette di memorizzare i frammenti di codice e inserirli in file aperti
Comment[kk]=Код үзінділерін сақтап, керегінде ашық файлдарға енгізу плагині
Comment[nb]=Dette programtillegget kan lagre kodebiter og sette dem inn i åpne filer
Comment[nds]=Dit Moduul wohrt Kodesnippels un föögt se na opmaakt Dateien in
Comment[nl]=Deze plugin biedt het opslaan van codefragmenten en voegt ze in in open bestanden
Comment[pl]=Ta wtyczka umożliwia zapisanie wstawek kodu i wstawianie ich później otwartych plików
Comment[pt]=Este 'plugin' permite-lhe guardar excertos de código e inseri-los nos ficheiros abertos
Comment[pt_BR]=Este plugin permite armazenar trechos de código e inseri-los em arquivos abertos
Comment[ru]=Это расширение позволяет хранить фрагменты кода и вставлять их в открытые файлы.
Comment[sk]=Tento plugin umožňuje uložiť útržky kódu a vložiť ich do otvorených súborov
Comment[sl]=Vstavek omogoča shranjevanje izrezkov kode in njihovo vstavljanje v odprte datoteke
Comment[sv]=Insticksprogrammet gör det möjligt att lagra kodsnuttar och infoga dem i öppna filer
Comment[tr]=Bu eklenti, kod parçacıklarını depolamayı ve bu kod parçacıklarını açık olan dosyalara eklemeyi sağlar
Comment[uk]=За допомогою цього додатка можна зберігати фрагменти коду і вставляти їх до відкритих файлів
Comment[x-test]=xxThis plugin allows to store code snippets and insert them into open filesxx
Comment[zh_CN]=此插件允许存储代码片断并插入到打开的文件中去
Comment[zh_TW]=此外掛程式允許儲存程式碼片段，並將它們插入開啟的檔案中
Name=Code Snippets Support
Name[bg]=Поддръжка на отрязъци от код
Name[bs]=Podrška za isječke koda
Name[ca]=Implementació de retalls de codi
Name[ca@valencia]=Implementació de retalls de codi
Name[da]=Understøttelse af kodestumper
Name[de]=Unterstützung für Textbausteine
Name[el]=Υποστήριξη αποσπασμάτων κώδικα
Name[en_GB]=Code Snippets Support
Name[es]=Implementación de fragmentos de código
Name[et]=Koodijuppide toetus
Name[fi]=Koodikatkelmatuki
Name[fr]=Prise en charge des fragments de code
Name[gl]=Soporte de fragmentos de código
Name[hu]=Kódtöredékek támogatás
Name[it]=Supporto frammenti di codice
Name[ja]=コードスニペットのサポート
Name[kk]=Код фрагменттері
Name[nb]=Støtte for kodebiter
Name[nds]=Kodesnippels-Ünnerstütten
Name[nl]=Ondersteuning voor codeknipsels
Name[pa]=ਕੋਡ ਸਨਿੱਪਟ ਸਹਿਯੋਗ
Name[pl]=Obsługa wstawek kodu
Name[pt]=Suporte para Excertos de Código
Name[pt_BR]=Suporte a trechos de código
Name[ru]=Поддержка фрагментов кода
Name[sk]=Podpora útržkov kódu
Name[sl]=Podpora za izrezke kode
Name[sv]=Stöd för kodsnuttar
Name[tr]=Kod Parçacıkları Desteği
Name[ug]=كود پۇرۇچلىرىنى قوللاش
Name[uk]=Підтримка фрагментів коду
Name[x-test]=xxCode Snippets Supportxx
Name[zh_CN]=代码片断支持
Name[zh_TW]=程式碼片段支援
GenericName=Code Snippets Support
GenericName[bg]=Поддръжка на отрязъци от код
GenericName[bs]=Podrška za isječke koda
GenericName[ca]=Implementació de retalls de codi
GenericName[ca@valencia]=Implementació de retalls de codi
GenericName[da]=Understøttelse af kodestumper
GenericName[de]=Unterstützung für Textbausteine
GenericName[el]=Υποστήριξη αποσπασμάτων κώδικα
GenericName[en_GB]=Code Snippets Support
GenericName[es]=Implementación de fragmentos de código
GenericName[et]=Koodijuppide toetus
GenericName[fi]=Koodikatkelmatuki
GenericName[fr]=Prise en charge des fragments de code
GenericName[gl]=Soporte de fragmentos de código
GenericName[hu]=Kódtöredékek támogatás
GenericName[it]=Supporto frammenti di codice
GenericName[ja]=コードスニペットのサポート
GenericName[kk]=Код фрагменттері
GenericName[nb]=Støtte for kodebiter
GenericName[nds]=Kodesnippels-Ünnerstütten
GenericName[nl]=Ondersteuning voor codeknipsels
GenericName[pl]=Obsługa wstawek kodu
GenericName[pt]=Suporte para Excertos de Código
GenericName[pt_BR]=Suporte a trechos de código
GenericName[ru]=Поддержка фрагментов кода
GenericName[sk]=Podpora útržkov kódu
GenericName[sl]=Podpora za izrezke kode
GenericName[sv]=Stöd för kodsnuttar
GenericName[tr]=Kod Parçacıkları Desteği
GenericName[ug]=كود پۇرۇچلىرىنى قوللاش
GenericName[uk]=Підтримка фрагментів коду
GenericName[x-test]=xxCode Snippets Supportxx
GenericName[zh_CN]=代码片断支持
GenericName[zh_TW]=程式碼片段支援
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevsnippet
X-KDE-PluginInfo-Name=kdevsnippet
X-KDE-PluginInfo-Author=Robert Gruber, Milian Wolff
X-KDE-PluginInfo-Version=0.75
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Mode=GUI
